@@ -9,17 +9,17 @@ async fn main() {
     "rmw upnp test",
     port,
     duration,
-    &|gateway, ext_port, ip, port| {
+    Box::new(|gateway, ext_port, ip, port| {
       println!(
         "upnp success: ( {}:{} -> {}:{} )",
         gateway, ext_port, ip, port
       );
       exit(0);
-    },
-    &|err| {
+    }),
+    Box::new(|err| {
       println!("upnp error: {}", err);
       exit(0);
-    },
+    }),
   )
   .await;
 }
