@@ -16,8 +16,8 @@ pub async fn daemon(
   name: &str,
   port: u16,
   duration: u32,
-  resolve: &dyn Fn(SocketAddrV4, u16, Ipv4Addr, u16),
-  reject: &dyn Fn(&dyn std::error::Error),
+  resolve: Box<dyn Fn(SocketAddrV4, u16, Ipv4Addr, u16) + Send>,
+  reject: Box<dyn Fn(&dyn std::error::Error) + Send>,
 ) {
   let mut local_ip = Ipv4Addr::UNSPECIFIED;
   let mut pre_gateway = SocketAddrV4::new(local_ip, 0);
